Python: package gdbm_compat

gdbm_compat | index /home/savannah/projects/gdbm_compat/gdbm_compat/__init__.py

`The following code is Public Domain.
Written by Tim Savannah, 2016.
The following methods allow you to use a gdbm database of a different version. It may not work in all cases, but is better than a flat-out error.`

Package Contents
`` |  |

Functions
`` |  | convert_to_1_10(filename) `convert_to_1_10 - Convert a gdbm database to format 1.10 Returns a filename of the converted database.` convert_to_1_8(filename) `convert_to_1_8 - Convert a gdbm database to format 1.8 Returns a filename of the converted database` get_magic_number(filename) `get_magic_number - Gets the magic number associated with the gdbm database filename provided @return <bytes> - Bytes of magic number` is_1_10(filename) `is_1_10 - Checks if database is in 1.10 format` is_1_8(filename) `is_1_8 - Checks if database is in 1.8 format.` replace_magic_number(filename, newMagic)

Data
`` |  | __all__ = ('convert_to_1_10', 'convert_to_1_8', 'replace_magic_number', 'get_magic_number', 'is_1_8', 'is_1_10', 'open')